#
# frontier_tomcat :   RPM Spec file for frontier tomcat distribution
# Author: Flavia Donno <Flavia.Donno@cern.ch>
# Creation Date: 28 Jul 2010
#
Summary: FroNTier Tomcat distribution
Name: frontier-tomcat

# IMROTANT: the Version signifies:
# 	the apache-tomecat version, concatinated (by underscore) with the version of frontier-servlet
#	The version of frontier-servlet is taken from http://frontier.cern.ch/dist/
# Example: tomcat version: 6.0.33, frontier-serevlet version: 3.29 produce: 6.0.33_3.29
%define version_tomcat 6.0.35
%define version_servlet 3.29
#TBD: Attempt to use symbolic code as: Version: %{version_tomcat}_%{version_servlet}
Version: 6.0.35_3.29
#TBD: something like: Version: %{version_tomcat}_%{version_servlet}

Release: 2
License: GPL
Group: System/Server
Packager: David Front <david.front@cern.ch>
Source0: %{name}-%{version}-%{release}.tar.gz
%define dirname %{name}
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version_tomcat}-%{release}-root
Prefix: /usr/share/frontier-tomcat
Requires: java
Obsoletes: frontier-servlet 
%define etcdir /etc/tomcat/
%define servletsConf %{etcdir}servlets.conf
%define initdTomcatScript /etc/init.d/frontier-tomcat
%define servletsPasswd %{etcdir}servlets.passwd
#%define prefix_etcdir %{prefix}/etc/
#%define servlets_conf_util %{prefix_etcdir}servletsConfUtil.py 
%define sourceConfig \
	CONFIG_FILE=/etc/tomcat/tomcat.conf;\
	export FRONTIER_USER=dbfrontier;\
	if [ -s ${CONFIG_FILE} ]; then\
		source ${CONFIG_FILE};\
	fi

%description
FroNTier-Tomcat server distribution, including its servlets.
See: http://frontier.cern.ch/dist/rpms/frontier-tomcatREADME

%prep
%setup -c %{dirname} -n %{dirname}

%build
wget http://frontier.cern.ch/dist/Frontier_%{version_servlet}.war 

%install

/bin/rm -rf $RPM_BUILD_ROOT
mkdir -p %{buildroot}%{prefix} %{buildroot}%{etcdir}

# wget the apache-tomcat tarball
# Consider moving this to rpm install time
wget  -O $RPM_BUILD_ROOT%{prefix}/apache-tomcat-%{version_tomcat}.tar.gz http://www.apache.org/dist/tomcat/tomcat-6/v%{version_tomcat}/bin/apache-tomcat-%{version_tomcat}.tar.gz

# Extract files from the tar ball
pushd $RPM_BUILD_ROOT%{prefix}
tar zxf $RPM_BUILD_ROOT%{prefix}/apache-tomcat-%{version_tomcat}.tar.gz
popd

#Dave Dykstra: rm things that are in the standard apache-tomcat package:
# everything in tomcat/webapps (and tomcat/conf/Catalina/localhost/)
rm -r $RPM_BUILD_ROOT%{prefix}/apache-tomcat-%{version_tomcat}/webapps

rm $RPM_BUILD_ROOT%{prefix}/apache-tomcat-%{version_tomcat}/conf/server.xml
rmdir $RPM_BUILD_ROOT%{prefix}/apache-tomcat-%{version_tomcat}/logs

#TBD: consider using unproto here, if possible
cp %{_maindir}/scripts/unproto.sh $RPM_BUILD_ROOT%{prefix}/
cp -R %{_builddir}/%{dirname}/* $RPM_BUILD_ROOT%{prefix}/

# for servlets.conf
mv %{_builddir}/%{name}%{etcdir}/servlets.confConstants $RPM_BUILD_ROOT%{etcdir}
chmod 444 $RPM_BUILD_ROOT%{etcdir}/servlets.confConstants

sed -e '1,$ {s:@@@version_servlet@@@:'%{version_servlet}':g}' %{_builddir}/%{dirname}/etc/servletsConfUtil.py.proto> $RPM_BUILD_ROOT%{prefix}/etc/servletsConfUtil.py
chmod 755 $RPM_BUILD_ROOT%{prefix}/etc/servletsConfUtil.py
sed -e '1,$ {s:@@@version@@@:'%{version_tomcat}':g}' %{_builddir}/%{dirname}/etc/frontier-tomcat-configurator.proto> $RPM_BUILD_ROOT%{prefix}/etc/frontier-tomcat-configurator
chmod 700 $RPM_BUILD_ROOT%{prefix}/etc/frontier-tomcat-configurator

rm -rf `find $RPM_BUILD_ROOT%{prefix}|grep '/\.svn'`

%pre

# Verify that prerequisite files exist
for f in %{servletsConf} %{servletsPasswd}; do
	if [ ! -s ${f} ]; then
		echo "ERROR: Missing file: ${f}. Cannot install."
		exit 1
	fi
done

if [ ${RPM_INSTALL_PREFIX} == '/' ]; then
	echo "ERROR: RPM_INSTALL_PREFIX can not be '/'. Try another directory."
	exit 1
fi

%sourceConfig
#Consider: useradd, if user is missing 
if ! getent passwd ${FRONTIER_USER} >/dev/null 2>&1 ; then # Fail if ${FRONTIER_USER} does not exist:
      echo "ERROR: Non existent ${FRONTIER_USER} account."
      exit 1
fi
## End: Handle FRONTIER_USER

ps -ef | grep tomcat | grep java 2>/dev/null
status=$?
if [ ${status} -eq 0 ]; then
   echo "Stopping the frontier-tomcat service"
   /sbin/service frontier-tomcat stop
   if [ ! $? -eq 0 ]; then
       echo "ERROR: Failed to stop frontier-tomcat: rc: $?"
       exit 1
   fi
fi

%post
%sourceConfig

export FRONTIER_PREFIX=${RPM_INSTALL_PREFIX} # TBD: get rid of this
if [ -z "${FRONTIER_TOMCAT_LOGS}" ]; then
	export FRONTIER_TOMCAT_LOGS="/data/tomcat_logs"
fi

if [ -z "${PID_DIR}" ]; then
	export PID_DIR="/var/run/tomcat"
fi


export UNPROTO_SH="${RPM_INSTALL_PREFIX}/unproto.sh"

cd ${RPM_INSTALL_PREFIX}
./etc/frontier-tomcat-configurator
status=$?
if [ $status -eq 0 ]; then

   /bin/cp ${RPM_INSTALL_PREFIX}/etc/frontier-tomcat %{initdTomcatScript}
   /bin/chown root:root %{initdTomcatScript}
   /bin/chmod 755 %{initdTomcatScript}

   /sbin/chkconfig --add frontier-tomcat
   /sbin/chkconfig frontier-tomcat on

   /sbin/service frontier-tomcat status 1>/dev/null
   if [ $? -eq 0 ]; then # Is running, first stop it 
      /sbin/service frontier-tomcat stop 1>/dev/null
      sleep 2
      if [ ! $? -eq 0 ]; then
          echo "ERROR: failed to stop running frontier-tomcat. Dangling installation. Consider: rpm -e %{name}-%{version}-%{release}"
          exit 1
      fi
   fi
   /sbin/service frontier-tomcat start 1>/dev/null
   if [ ! $? -eq 0 ]; then
      echo "ERROR: failed to start frontier-tomcat. Dangling installation. Consider: rpm -e %{name}-%{version}-%{release}"
      exit 1
   fi
else
   echo "ERROR: failed to install %{name}. Dangling installation. PLEASE DO: rpm -e %{name}-%{version}-%{release}. If previous release was installed, it may still be running"
   exit 1
fi

%preun
%sourceConfig
	if [ $1 -eq 0 ]; then
	ps -ef | grep tomcat | grep java 2>/dev/null
	status=$?
	if [ ${status} -eq 0 ]; then
		echo "Stopping the frontier-tomcat service"
		/sbin/service frontier-tomcat stop
		if [ ! $? -eq 0 ]; then
			echo "ERROR: failed to stop frontier-tomcat. Will unstall %{name}-%{version}-%{release}. Verify that there are no dangling processes (ps -efw|grep tomcat)"
			exit 0
		fi
	fi
	serv=`eval chkconfig --list frontier-tomcat 2>/dev/null | awk -F" " '{print $1}'`
	if [ "x${serv}" = "xfrontier-tomcat" ]; then
		echo "Removing the frontier-tomcat service from chkconfig"
		/sbin/chkconfig --del frontier-tomcat
	fi

	# Removing lines from cron job
	echo "Removing relative cron job lines for the ${FRONTIER_USER} user ..."
	if [ -e /var/spool/cron/${FRONTIER_USER} ]; then
  		sed -i '/^0 0.*\/tomcat_rotate/d' /var/spool/cron/${FRONTIER_USER}
	fi
#Do I want to support multiple releases, may it be important to keep the order for this scenario?
fi

%postun
%sourceConfig
if [ $1 -eq 0 ]; then
	/bin/rm -f %{initdTomcatScript}
	/bin/rm -f ${RPM_INSTALL_PREFIX}/etc/modifiedqueries_rotate.sh
	/bin/rm -f ${RPM_INSTALL_PREFIX}/etc/cron
	/bin/rm -f ${RPM_INSTALL_PREFIX}/etc/tomcat.logrotate
	/bin/rm -f ${RPM_INSTALL_PREFIX}/etc/modifiedqueries.logrotate
	/bin/rm -f ${RPM_INSTALL_PREFIX}/etc/frontier-tomcat
	/bin/rm -f ${RPM_INSTALL_PREFIX}/etc/tomcat_rotate.sh
	/bin/rm -f ${RPM_INSTALL_PREFIX}/bin/findmodifiedqueries
	# Removing all pointed to by symbolic link and itself
	/bin/rm -fr ${RPM_INSTALL_PREFIX}/apache-tomcat-%{version_tomcat} # Beware: rm -r
	/bin/rm -f ${RPM_INSTALL_PREFIX}/tomcat
fi

%clean
%{__rm} -rf %{buildroot}

%files
#tomcat related
# consider: specify exact list of files, for better control.
%verify(not user group) %{prefix}/
# Servlet related
%verify(not user group) %{etcdir}servlets.confConstants
#TBD either specify all files or none here
##%{prefix_etcdir}config.properties.proto
##%{prefix_etcdir}servlet.xml.proto
##%{prefix_etcdir}web.xml.proto
##%{servlets_conf_util}
#TBD: get rid of the following files:
##%{prefix_etcdir}servletsConfUtil.pyo
##%{prefix_etcdir}servletsConfUtil.pyc

%changelog
